@@ -17,6 +17,7 @@ from agentuity.server import (
 
 from agentuity.io.email import EmailAttachment
 from agentuity.io.discord import DiscordMessage
+from agentuity.io.telegram import Telegram, parse_telegram
 from agentuity.apis.discord import DiscordApi
 
 __all__ = [
@@ -29,5 +30,7 @@ __all__ = [
     "autostart",
     "EmailAttachment",
     "DiscordMessage",
+    "Telegram",
+    "parse_telegram",
     "DiscordApi",
 ]
