@@ -406,6 +406,18 @@ async def handle_agent_request(request: web.Request):
 
                 span.set_attribute("@agentuity/scope", scope)
 
+                # Devmode: make sure to data in metadata since its not coming through catalyst
+                if metadata is None:
+                    metadata = {}
+                if "headers" not in metadata:
+                    metadata["headers"] = {}
+                    for k, v in request.headers.items():
+                        metadata["headers"][k] = v
+                if "method" not in metadata:
+                    metadata["method"] = request.method
+                if "url" not in metadata:
+                    metadata["url"] = str(request.url)
+
                 agent_request = AgentRequest(
                     trigger, metadata, contentType, request.content
                 )
@@ -434,7 +446,7 @@ async def handle_agent_request(request: web.Request):
                     agent=agent,
                     agents_by_id=agents_by_id,
                     port=port,
-                    run_id=run_id,
+                    session_id=run_id,
                     scope=scope,
                 )
                 agent_response = AgentResponse(
@@ -573,26 +585,38 @@ async def handle_index(request):
 
 def get_agent_filepath(agent_name: str) -> str:
     """
-    Get the filepath for an agent, checking both new and legacy directory structures.
-    First tries the new 'agentuity-agents' directory, then falls back to the legacy 'agents' directory.
+    Get the filepath for an agent, checking directory structures in order of preference:
+    1. agentuity_agents (new underscore format)
+    2. agentuity-agents (legacy hyphen format)
+    3. agents (legacy format)
     """
     safe_name = safe_python_name(agent_name)
 
-    # Try new structure first
-    new_path = os.path.join(os.getcwd(), "agentuity-agents", safe_name, "agent.py")
-    if os.path.exists(new_path):
-        return new_path
+    # Try new underscore structure first
+    underscore_path = os.path.join(
+        os.getcwd(), "agentuity_agents", safe_name, "agent.py"
+    )
+    if os.path.exists(underscore_path):
+        return underscore_path
+
+    # Try hyphen structure second
+    hyphen_path = os.path.join(os.getcwd(), "agentuity-agents", safe_name, "agent.py")
+    if os.path.exists(hyphen_path):
+        logger.warning(
+            f"Using hyphenated agents directory structure for {agent_name}. Consider migrating to 'agentuity_agents' directory."
+        )
+        return hyphen_path
 
     # Fall back to legacy structure for backwards compatibility
     legacy_path = os.path.join(os.getcwd(), "agents", safe_name, "agent.py")
     if os.path.exists(legacy_path):
         logger.warning(
-            f"Using legacy agents directory structure for {agent_name}. Consider migrating to 'agentuity-agents' directory."
+            f"Using legacy agents directory structure for {agent_name}. Consider migrating to 'agentuity_agents' directory."
         )
         return legacy_path
 
-    # Return new path as default (for error reporting)
-    return new_path
+    # Return underscore path as default (for error reporting)
+    return underscore_path
 
 
 def load_config() -> Tuple[Optional[dict], str]:
